Releases
========

This software is still considered experimental.
We will start publishing release notes at a future time.

Any release my introduce breaking changes to any of the protocols or options.

next
----

* (describe new work here)


25.4.0
------

- Proper metadata for PyPI
- Use ``app_versions`` to properly indicate our version to the peer.
- debug message output
- ``status`` command in the TUI
- add explicit ping/pong
- use ``furo`` theme for docs; much editing
- Drop Python 3.9
- finish, expose "policy" and "permissions" APIs


24.12.0
-------

- First release containing these release notes.
- allow non-localhost connections (#37)
- enable allow-list style connection permission
- beginning of "policy" and "permissions" APIs



24.3.2
------

Last release before this document existed.
